@@ -21,7 +21,7 @@
 #define OPENBLAS_CORE_ARMV7
 #define OPENBLAS_CHAR_CORENAME "ARMV7"
 #define OPENBLAS_GEMM_MULTITHREAD_THRESHOLD	4
-#define OPENBLAS_VERSION "OpenBLAS 0.3.30"
+#define OPENBLAS_VERSION "OpenBLAS 0.3.31"
 /*This is only for "make install" target.*/
 
 #if defined(OPENBLAS_OS_WINNT) || defined(OPENBLAS_OS_CYGWIN_NT) || defined(OPENBLAS_OS_INTERIX)
@@ -63,6 +63,13 @@ typedef unsigned long BLASULONG;
 typedef uint16_t bfloat16;
 #endif
 
+#if defined(__GNUC__) && (__GNUC__ >= 12)
+typedef _Float16 hfloat16;
+#else
+#include <stdint.h>
+typedef uint16_t hfloat16;
+#endif
+
 #ifdef OPENBLAS_USE64BITINT
 typedef BLASLONG blasint;
 #else
